{%- from "ironic/map.jinja" import api with context %}
{%- if api.enabled %}
include:
  - ironic._common
  - ironic.db.offline_sync

ironic_api_packages:
  pkg.installed:
  - names: {{ api.pkgs }}
  - install_recommends: False
  - require_in:
    - sls: ironic._common
    - sls: ironic.db.offline_sync

{%- if api.logging.log_handlers.get('fluentd',{}).get('enabled', False) %}
ironic_api_fluentd_logger_package:
  pkg.installed:
    - name: python-fluent-logger
{%- endif %}

{% if api.logging.log_appender %}
ironic_api_logging_conf:
  file.managed:
    - name: /etc/ironic/logging/logging-{{ api.service }}.conf
    - source: salt://oslo_templates/files/logging/_logging.conf
    - template: jinja
    - user: ironic
    - group: ironic
    - makedirs: True
    - require_in:
      - sls: ironic.db.offline_sync
    - require:
      - pkg: ironic_api_packages
{%- if api.logging.log_handlers.get('fluentd',{}).get('enabled', False) %}
      - pkg: ironic_api_fluentd_logger_package
{%- endif %}
    - defaults:
        service_name: ironic-api
        _data: {{ api.logging }}
    - watch_in:
      - service: {{ api.service }}

{{ api.service }}_default:
  file.managed:
    - name: /etc/default/{{ api.service }}
    - source: salt://ironic/files/default
    - template: jinja
    - require:
      - pkg: ironic_api_packages
    - defaults:
        service_name: {{ api.service }}
        values: {{ api.logging }}
    - watch_in:
      - service: {{ api.service }}
{%- else %}
{{ api.service }}_default:
  file.absent:
    - name: /etc/default/{{ api.service }}
    - watch_in:
      - service: {{ api.service }}
{%- endif %}

{{ api.service }}:
  service.running:
    - enable: true
    - full_restart: true
    - require:
      - sls: ironic._common
      - sls: ironic.db.offline_sync
    - watch:
      - file: /etc/ironic/ironic.conf
      - file: /etc/ironic/policy.json

/etc/ironic/{{ api.get('oslo_policy', {}).get('policy_file', 'policy.json') }}:
  file.managed:
  - source: salt://ironic/files/{{ api.version }}/policy.json
  - template: jinja
  - require:
    - pkg: ironic_api_packages
  - require_in:
    - sls: ironic.db.offline_sync

{%- endif %}
