{%- from "ironic/map.jinja" import api,conductor, client with context %}

{%- if api.get("enabled", False) %}
  {%- set ironic, service_name = api, 'api' %}
{%- elif conductor.get("enabled", False) %}
  {%- set ironic, service_name = conductor, 'conductor' %}
{%- endif %}

ironic_pre:
  test.show_notification:
    - text: "Running ironic.upgrade.pre"

/etc/ironic/ironic.conf:
  file.managed:
  - source: salt://ironic/files/{{ ironic.version }}/ironic.conf
  - template: jinja

include:
 - ironic.db.online_sync

{%- set os_content = salt['mine.get']('I@keystone:client:os_client_config:enabled:true', 'keystone_os_client_config', 'compound').values()[0] %}
keystone_os_client_config:
  file.managed:
    - name: /etc/openstack/clouds.yml
    - contents: |
        {{ os_content |yaml(False)|indent(8) }}
    - user: 'root'
    - group: 'root'
    - makedirs: True
    - unless: test -f /etc/openstack/clouds.yml

{%- if conductor.get('enabled', false) %}
  {%- if conductor.http_images is defined %}
    {%- for image in conductor.http_images %}

image_{{ image.name }}:
  file.managed:
    - name: {{ conductor.http_root }}/{{ image.name }}
    - source: {{ image.source }}
    {%- if image.md5summ is defined %}
    - source_hash: md5={{ image.md5summ }}
    {%- else %}
    - source_hash: {{ image.hash_file }}
    {%- endif %}
    - user: 'ironic'
    - group: 'ironic'
    {%- endfor %}
  {%- endif %}
  {%- if client.get('enabled', false) %}
    {%- for identity_name, nodes in client.nodes.iteritems() %}
      {%- for node in nodes %}
node_{{ node.name }}_present:
  ironicv1.node_present:
    - name: {{ node.name }}
    - driver: {{ node.driver }}
    - driver_info: {{ node.driver_info|default({}) }}
    - cloud_name: {{ client.cloud_name }}
    - properties: {{ node.properties|default({}) }}
    {%- if node.network_interface is defined %}
    - network_interface: {{ node.network_interface }}
    {%- endif %}
    {%- if node.storage_interface is defined %}
    - storage_interface: {{ node.storage_interface }}
    {%- endif %}
    {%- if node.microversion is defined %}
    - microversion: "{{ node.microversion }}"
    {%- endif %}
      {%- endfor %} # end for nodes
    {%- endfor %} # end client.nodes.iteritems
  {%- endif %}
{%- endif %}
